local myname="ZifnabsMapper"
local Me=CreateFrame("Frame",myname)
if not ZifnabsMod then ZifnabsMod={map=Me} else ZifnabsMod.map=Me end
local mod
local L
local C
local db

local worldmapPins={}
local uimid2znr={}

Me.WorldMapDataProvider = CreateFromMixins(MapCanvasDataProviderMixin)
ZifnabsWorldmapPinMixin = CreateFromMixins(MapCanvasPinMixin)

-- local id=WorldmapFrame:GetMapID()

-- --------------------------------------------------------------------------------------
-- INITIALIZE
-- --------------------------------------------------------------------------------------
function Me:Initialize(fwinfo)
	mod=fwinfo.mod
	L=fwinfo.L
	C=fwinfo.C
	db=fwinfo.db
	for znr,info in pairs(C.zones) do
		if info.mid then uimid2znr[info.mid]=znr end
	end
end
function Me:PostInit() 
	WorldMapFrame:AddDataProvider(Me.WorldMapDataProvider)
	Me.WorldMapDataProvider:RefreshAllData() 
end

-- --------------------------------------------------------------------------------------
-- WORLDMAP DATAPROVIDER : REMOVE ALL DATA
-- --------------------------------------------------------------------------------------
function Me.WorldMapDataProvider:RemoveAllData()
	self:GetMap():RemoveAllPinsByTemplate("ZifnabsWorldmapPinTemplate")
	wipe(worldmapPins)
end

-- --------------------------------------------------------------------------------------
-- WORLDMAP DATAPROVIDER : REFRESH ALL DATA
-- --------------------------------------------------------------------------------------
function Me.WorldMapDataProvider:RefreshAllData(fromOnShow)
	self:RemoveAllData()
	local uiMapID = self:GetMap():GetMapID()
	if uiMapID then
		local zone_nr=uimid2znr[uiMapID]
		if zone_nr then
			local interested=mod.loc:WORLDMAP_ZONE_CHANGED(zone_nr)
			for modname,info in pairs(interested) do
				for nr,data in pairs(info.list or {}) do
					table.insert(worldmapPins, self:GetMap():AcquirePin("ZifnabsWorldmapPinTemplate", data))
				end
			end
		end
	end
end

-- --------------------------------------------------------------------------------------
-- WORLDMAP PIN MIXIN : ON LOAD
-- --------------------------------------------------------------------------------------
function ZifnabsWorldmapPinMixin:OnLoad()
	self:UseFrameLevelType("PIN_FRAME_LEVEL_AREA_POI")
	self:SetScalingLimits(1, 1.0, 1.2);
end

-- --------------------------------------------------------------------------------------
-- WORLDMAP PIN MIXIN : ON ACQUIRED
-- --------------------------------------------------------------------------------------
function ZifnabsWorldmapPinMixin:OnAcquired(data) -- mal schauen welche infos hier rein sollen
	local x,y,zone,zone_nr=mod.loc:ParseLoc(data.pos)
	self:SetPosition(x, y)
	self.tooltipText=data.tooltip
	self.click=data.click
	self.data=data
	if data.icon then 
		local iconname="Interface/AddOns/Zifnabs/Icons/"..data.icon..".tga"
		self:SetBackdrop(nil)
		self.texture:SetTexture(iconname)
		self:SetSize(12,12)
	else
		self:SetBackdrop({bgFile = "Interface/Tooltips/UI-Tooltip-Background", edgeFile = nil});
		self.texture:SetTexture(nil)
		self:SetSize(8,8)
		self:SetBackdropColor(1,0,0,1)
	end
	self.texture:SetTexCoord(0, 1, 0, 1)
	self.texture:SetVertexColor(1, 1, 1, 1)
	self:EnableMouse(true)
	self:Show()
end

-- --------------------------------------------------------------------------------------
-- WORLDMAP PIN MIXIN : ON MOUSE EVENTS
-- --------------------------------------------------------------------------------------
function ZifnabsWorldmapPinMixin:OnMouseEnter() 
print("Mouse Enter")
end
function ZifnabsWorldmapPinMixin:OnMouseLeave()
print("Mouse Leave")
end
function ZifnabsWorldmapPinMixin:OnClick(button)
print("Mouse Click")
end